#!/usr/bin/env python
# -*- encoding: utf-8 -*-
"""
@File    :   fedhf\api\message\__init__.py
@Time    :   2021/10/19 21:29:20
@Author  :   Bingjie Yan
@Email   :   bj.yan.pa@qq.com
"""

__all__ = []

from .base_message import BaseMessage as Message
